# Changelog

## 4.90.0 (2026-03-31)

Full Changelog: [v4.89.0...v4.90.0](https://github.com/team-telnyx/telnyx-python/compare/v4.89.0...v4.90.0)

### Features

* **lib:** add ED25519 webhook signature verification ([18be54b](https://github.com/team-telnyx/telnyx-python/commit/18be54bff12109ba79b6ba2a80a881fdfaa523f0))

## 4.89.0 (2026-03-30)

Full Changelog: [v4.88.1...v4.89.0](https://github.com/team-telnyx/telnyx-python/compare/v4.88.1...v4.89.0)

### Features

* **lib:** add Speech-to-Text WebSocket streaming support ([b7e059a](https://github.com/team-telnyx/telnyx-python/commit/b7e059ab7d86a982f8773a420867f827fde2ca51))


### Bug Fixes

* resolve pyright strict mode type errors ([3283d71](https://github.com/team-telnyx/telnyx-python/commit/3283d71d81d515147e7c2b96acf541f38ae34f9c))
* resolve ruff import sorting errors ([f210455](https://github.com/team-telnyx/telnyx-python/commit/f2104551e00dedd2db3bab6596e58591efd899ef))

## 4.88.1 (2026-03-28)

Full Changelog: [v4.88.0...v4.88.1](https://github.com/team-telnyx/telnyx-python/compare/v4.88.0...v4.88.1)

### Bug Fixes

* **python:** add edition python.2025-11-20 for OIDC support ([018532e](https://github.com/team-telnyx/telnyx-python/commit/018532e7217cd1a3b03530b76d84a9f9d2302528))


### Chores

* sync repo ([a70b9c2](https://github.com/team-telnyx/telnyx-python/commit/a70b9c2922e4196876a3c68057e461c63cc44f5f))
